'use strict';

const kit = require('@nuxt/kit');
const vite = require('vite');

async function getViteConfig(rootDir = process.cwd()) {
  const nuxt = await kit.loadNuxt({
    cwd: rootDir,
    dev: false,
    overrides: {
      ssr: false,
      app: {
        rootId: "nuxt-test"
      }
    }
  });
  return new Promise((resolve, reject) => {
    nuxt.hook("vite:extendConfig", (config) => {
      resolve(config);
      throw new Error("_stop_");
    });
    kit.buildNuxt(nuxt).catch((err) => {
      if (!err.toString().includes("_stop_")) {
        reject(err);
      }
    });
  }).finally(() => nuxt.close());
}
async function getVitestConfig() {
  const viteConfig = await getViteConfig();
  return {
    ...viteConfig,
    test: {
      environment: "nuxt",
      deps: {
        inline: [/\/(nuxt|nuxt3)\//, /^#/, "vue", "vitest-environment-nuxt"]
      }
    }
  };
}
async function defineConfigWithNuxtEnv(config = {}) {
  return vite.defineConfig(async () => {
    return vite.mergeConfig(await getVitestConfig(), config);
  });
}

exports.defineConfigWithNuxtEnv = defineConfigWithNuxtEnv;
exports.getVitestConfig = getVitestConfig;
