import { loadNuxt, buildNuxt } from '@nuxt/kit';
import { defineConfig, mergeConfig } from 'vite';

async function getViteConfig(rootDir = process.cwd()) {
  const nuxt = await loadNuxt({
    cwd: rootDir,
    dev: false,
    overrides: {
      ssr: false,
      app: {
        rootId: "nuxt-test"
      }
    }
  });
  return new Promise((resolve, reject) => {
    nuxt.hook("vite:extendConfig", (config) => {
      resolve(config);
      throw new Error("_stop_");
    });
    buildNuxt(nuxt).catch((err) => {
      if (!err.toString().includes("_stop_")) {
        reject(err);
      }
    });
  }).finally(() => nuxt.close());
}
async function getVitestConfig() {
  const viteConfig = await getViteConfig();
  return {
    ...viteConfig,
    test: {
      environment: "nuxt",
      deps: {
        inline: [/\/(nuxt|nuxt3)\//, /^#/, "vue", "vitest-environment-nuxt"]
      }
    }
  };
}
async function defineConfigWithNuxtEnv(config = {}) {
  return defineConfig(async () => {
    return mergeConfig(await getVitestConfig(), config);
  });
}

export { defineConfigWithNuxtEnv, getVitestConfig };
