'use strict';

const h3 = require('h3');
const testUtils = require('@vue/test-utils');
const vue = require('vue');
const NuxtRoot = require('#build/root-component.mjs');

function registerEndpoint(url, handler) {
  if (!window.__app)
    return;
  window.__app.use("/_" + url, h3.defineEventHandler(handler));
  window.__registry.add(url);
}

const RouterLink = defineComponent({
  functional: true,
  props: {
    to: String,
    custom: Boolean,
    replace: Boolean,
    activeClass: String,
    exactActiveClass: String,
    ariaCurrentValue: String
  },
  setup: (props, { slots }) => {
    const navigate = () => {
    };
    return () => {
      const route = props.to ? useRouter().resolve(props.to) : {};
      return props.custom ? slots.default?.({ href: props.to, navigate, route }) : h("a", { href: props.to, onClick: (e) => {
        e.preventDefault();
        return navigate();
      } }, slots);
    };
  }
});

async function mountSuspended(component) {
  return new Promise((resolve) => {
    const vm = testUtils.mount({
      setup: NuxtRoot.setup,
      render: () => vue.h(vue.Suspense, { onResolve: () => resolve(vm) }, { default: () => vue.h(component) })
    }, {
      global: {
        components: {
          RouterLink
        }
      }
    });
  });
}

exports.mountSuspended = mountSuspended;
exports.registerEndpoint = registerEndpoint;
